@@ -9,6 +9,7 @@ from flaskext.debugtoolbar import DebugToolbarExtension
 
 app = Flask(__name__)
 app.config['DEBUG_TB_INTERCEPT_REDIRECTS'] = True
+app.config['DEBUG'] = True
 #app.config['DEBUG_TB_PANELS'] = (
 #    'flaskext.debugtoolbar.panels.headers.HeaderDebugPanel',
 #    'flaskext.debugtoolbar.panels.logger.LoggingPanel',
@@ -36,6 +37,10 @@ def redirect_example():
     response.set_cookie('test_cookie', '1')
     return response
 
+@app.route('/test/<foo>')
+def var_route(foo):
+    return render_template('index.html')
+
 if __name__ == "__main__":
     db.create_all()
 
